@@ -7,11 +7,12 @@ from six import add_metaclass
 USING_PYTHON2 = True if sys.version_info < (3, 0) else False
 
 if USING_PYTHON2:
-    str = unicode
+    str = unicode  # noqa
 
 class NumericStringType(type):
     _type = str
     _cast = float
+
     def __instancecheck__(self, other):
         try:
             if not isinstance(other, self._type):
